import os
import time
import unittest

from ..ssh_client.client import SSHClient


def str_time(fmt="%Y%m%d%H%M%S"):
    return time.strftime(fmt, time.localtime())


class TestClient(unittest.TestCase):

    def test_functions(self):
        ssh = SSHClient(os.getenv('HOST'), os.getenv('USER'), os.getenv('PASSWD'))
        ssh.connect()
        test_file = str_time() + ".log"
        ssh.invoke_exec("date")
        ssh.exec(f"echo \"Hello World\" > /tmp/{test_file}")
        ssh.download(f'/tmp/{test_file}', os.path.abspath(os.curdir))
        ssh.upload(os.path.join(os.path.abspath(os.curdir), f'{test_file}'), '/tmp')
        ssh.exec(f"cat /tmp/{test_file}")
        ssh.invoke_exec('ls')
        ssh.close()


if __name__ == '__main__':
    unittest.main()



import os
import tarfile
import zipfile


def zip_extract_to(zip_file, target_dir):
    with zipfile.ZipFile(zip_file) as z:
        z.extractall(target_dir)


def zip_extract(zip_file):
    target_dir, _ = os.path.splitext(zip_file)
    if os.path.isdir(target_dir):
        os.rmdir(target_dir)
    zip_extract_to(zip_file, target_dir)


def zip_create_to(target_dir, target, src_dir, *args):
    with zipfile.ZipFile(os.path.join(target_dir, target), 'w') as z:
        for file in args:
            z.write(os.path.join(src_dir, file), arcname=file)
        return target


def zip_create(target_dir, target, *args):
    zip_create_to(target_dir, target, target_dir, *args)


def tar_extract_to(tar_file, target_dir):
    with tarfile.TarFile(tar_file) as t:
        t.extractall(target_dir)


def tar_extract(tar_file):
    target_dir, _ = os.path.splitext(tar_file)
    if os.path.isdir(target_dir):
        os.rmdir(target_dir)
    tar_extract_to(tar_file, target_dir)


def tar_create_to(target_dir, target, src_dir, *args):
    with tarfile.open(os.path.join(target_dir, target), "w") as tar:
        for name in args:
            tar.add(os.path.join(src_dir, name), arcname=name)


def tar_create(target_dir, target, *args):
    tar_create_to(target_dir, target, target_dir, *args)



import logging
import subprocess

logger = logging.getLogger('ssh_client')


def shell_exec(cmd, check=False, capture_output=True, ignore_exit=False, timeout=120):
    if capture_output:
        p = subprocess.run(cmd, shell=True, check=check, capture_output=capture_output, timeout=timeout)
    else:
        p = subprocess.run(cmd, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL,
                           shell=True, check=check, capture_output=capture_output, timeout=timeout)
    logger.info(f"[{p.args}] --> {p.returncode}")
    if p.stdout:
        logger.info(str(p.stdout, encoding='utf-8'))
    if p.stderr:
        logger.info(str(p.stderr, encoding='utf-8'))

    if not ignore_exit:
        assert p.returncode == 0



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

install_requires = [
    "fabric==2.6.0",
    "paramiko==2.7.2",
    "invoke==1.6.0"
]

setuptools.setup(
    name="ssh-client-baoer",
    version="0.0.23",
    author="baoer",
    author_email="821832333@qq.com",
    description="SSH Client.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=install_requires,
    url="https://gitee.com/haitaoboy/ssh-client",
    project_urls={
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)
